@@ -246,12 +246,12 @@ void AtmosphereShowMySky::loadShaders()
 	{
 		if(!success)
 		{
-			qCritical("Error while compiling %s: %s", what, shader.log().toLatin1().constData());
+			qCCritical(Atmo, "Error while compiling %s: %s", what, shader.log().toLatin1().constData());
 			throw InitFailure("Shader compilation failed");
 		}
 		if(!shader.log().isEmpty())
 		{
-			qWarning("Warnings while compiling %s: %s", what, shader.log().toLatin1().constData());
+			qCWarning(Atmo, "Warnings while compiling %s: %s", what, shader.log().toLatin1().constData());
 		}
 	};
 
@@ -413,7 +413,7 @@ AtmosphereShowMySky::AtmosphereShowMySky(const double initialAltitude)
 	{
 		atmoRes = reducedResolution;
 		if (reducedResolution>1)
-			qDebug() << "Atmosphere runs with statically reduced resolution:" << reducedResolution;
+			qCDebug(Atmo) << "Atmosphere runs with statically reduced resolution:" << reducedResolution;
 	}
 
 	resolveFunctions();
@@ -425,7 +425,7 @@ AtmosphereShowMySky::AtmosphereShowMySky(const double initialAltitude)
 		if(!gl)
 			throw InitFailure(q_("Failed to get OpenGL 3.3 support functions"));
 
-		qDebug() << "Will load CalcMySky atmosphere model from" << pathToData;
+		qCDebug(Atmo) << "Will load CalcMySky atmosphere model from" << pathToData;
 		skySettings_.reset(new SkySettings);
 		auto& settings = *static_cast<SkySettings*>(skySettings_.get());
 		settings.altitude_ = initialAltitude;
@@ -630,7 +630,17 @@ Vec4f AtmosphereShowMySky::getMeanPixelValue()
 bool AtmosphereShowMySky::dynamicResolution(StelProjectorP prj, Vec3d &currPos, int width, int height)
 {
 	if (!flagDynamicResolution)
+	{
+		// There's nothing to do here, we're drawing in full resolution and full frame rate.
 		return false;
+	}
+
+	// If the scene is rendered in real time and is practically static,
+	// Stellarium generates approximately 18 frames per second.
+	// We draw about one atmosphere per second at full resolution.
+	// For faster-moving scenes, Stellarium increases the frame rate to the maximum,
+	// perhaps 50 frames per second depending on the hardware's capabilities.
+	// We draw about 10 atmospheres per second in reduced resolution.
 
 	const auto currFov=prj->getFov(), currFad=fader.getInterstate();
 	Vec3d currSun;
@@ -651,18 +661,15 @@ bool AtmosphereShowMySky::dynamicResolution(StelProjectorP prj, Vec3d &currPos,
 		dynResTimer--;                                              // count down to redraw
 		return true;
 	}
-	// if there is a timeout, we draw with full resolution
-	// if the change is too large, we draw with reduced resolution
-	atmoRes=timeout?1:reducedResolution;
+	// if the change is too big, we draw with reduced resolution, otherwise with full resolution
+	atmoRes=changed?reducedResolution:1;
 	if (prevRes!=atmoRes)
 	{
 		resizeRenderTarget(width, height);
-		bool verbose=qApp->property("verbose").toBool();
-		if (verbose)
-			qDebug() << "dynResTimer" << dynResTimer << "atmoRes" << atmoRes << "changeOfView" << changeOfView.norm() << changeOfView;
+		qCDebug(Atmo) << "dynResTimer" << dynResTimer << "atmoRes" << atmoRes << "changeOfView" << changeOfView.norm() << changeOfView;
 	}
 	// At reduced resolution, we hurry to redraw - at full resolution, we have time.
-	dynResTimer=timeout?17:5;
+	dynResTimer=changed?5:17;                                       // dynResTimer is like a clock divider.
 	prevRes=atmoRes;
 	prevFov=currFov;
 	prevFad=currFad;
