@@ -18,12 +18,14 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
+#include "StelLocaleMgr.hpp"
 #include "StelProjector.hpp"
 #include "Constellation.hpp"
 #include "StarMgr.hpp"
 #include "StelModuleMgr.hpp"
 #include "NebulaMgr.hpp"
 
+#include "StelSpeechMgr.hpp"
 #include "StelTexture.hpp"
 #include "StelPainter.hpp"
 #include "StelApp.hpp"
@@ -345,6 +347,28 @@ QString Constellation::getInfoLabel() const
 	return getCultureLabel(scMgr->getInfoLabelStyle());
 }
 
+void Constellation::setNarration(const QString &narration)
+{
+	this->narration=narration;
+}
+
+QString Constellation::getNarration(const StelCore *core, const InfoStringGroup &flags) const
+{
+	Q_UNUSED(flags)
+	const StelTranslator& trans = StelApp::getInstance().getLocaleMgr().getSkyCultureDescriptionsTranslator();
+
+	QString toBeSpoken=trans.qtranslate(narration);
+	// Strip away markdown elements like underscores or stars.
+	static const QRegularExpression latin("_([^_]{0,50})_");
+	static const QRegularExpression star("\\*([^\\*]{0,50})\\*");
+	QString stripped=toBeSpoken.replace(latin, "\\1").replace(star, "\\1");
+
+	qCDebug(Speech) << "Constellation name" << getEnglishName() << "narration:" << stripped;
+
+	// Try to get a little break between title and story.
+	return getNameI18n() + ". . . " + stripped;
+}
+
 QString Constellation::getCultureLabel(StelObject::CulturalDisplayStyle style) const
 {
 	static StelSkyCultureMgr *scMgr=GETSTELMODULE(StelSkyCultureMgr);
@@ -435,13 +459,7 @@ void Constellation::drawArtOptim(StelPainter& sPainter, const SphericalRegion& r
 			if (artTexture->bind()==false)
 				return;
 
-#ifdef Q_OS_LINUX
-			// Unfortunately applying aberration to the constellation artwork causes ugly artifacts visible on Linux.
-			// It is better to disable aberration in this case and have a tiny texture shift where it usually does not need to critically match.
-			sPainter.drawStelVertexArray(artPolygon, false, Vec3d(0.));
-#else
 			sPainter.drawStelVertexArray(artPolygon, false, obsVelocity);
-#endif
 		}
 	}
 }
@@ -570,6 +588,9 @@ QString Constellation::getInfoString(const StelCore *core, const InfoStringGroup
 		oss << QString("%1: <b>%2</b>").arg(q_("Type"), getObjectTypeI18n()) << "<br />";
 
 	oss << getSolarLunarInfoString(core, flags);
+
+	if (flags&Extra && !narration.isEmpty())
+		oss << QString("%1: ").arg(qc_("Legend", "constellation origin")) << StelUtils::wrapText(StelSkyCultureMgr::markdownToHTML(narration));
 	postProcessInfoString(str, flags);
 
 	return str;
